use crate::compare;

// Footnote references may appear within a footnote.
#[test]
fn test_1c8325a() {
    let src = r##"[^a]

[^a]: a[^b][^c]
[^b]: b
"##;
    let expected = r##"<p><a id="fnref1" href="#fn1" role="doc-noteref"><sup>1</sup></a></p>
<section role="doc-endnotes">
<hr>
<ol>
<li id="fn1">
<p>a<a id="fnref2" href="#fn2" role="doc-noteref"><sup>2</sup></a><a id="fnref3" href="#fn3" role="doc-noteref"><sup>3</sup></a><a href="#fnref1" role="doc-backlink">↩︎︎</a></p>
</li>
<li id="fn2">
<p>b<a href="#fnref2" role="doc-backlink">↩︎︎</a></p>
</li>
<li id="fn3">
<p><a href="#fnref3" role="doc-backlink">↩︎︎</a></p>
</li>
</ol>
</section>
"##;
    compare!(src, expected);
}

// Footnote references in unreferenced footnotes are ignored.
#[test]
fn test_9eab5c8() {
    let src = r##"para

[^a]: a[^b][^c]
[^b]: b
"##;
    let expected = r##"<p>para</p>
"##;
    compare!(src, expected);
}

// Footnotes may appear within footnotes.
#[test]
fn test_041f54c() {
    let src = r##"[^b]
[^a]

[^a]: [^b]: inner
"##;
    let expected = r##"<p><a id="fnref1" href="#fn1" role="doc-noteref"><sup>1</sup></a>
<a id="fnref2" href="#fn2" role="doc-noteref"><sup>2</sup></a></p>
<section role="doc-endnotes">
<hr>
<ol>
<li id="fn1">
<p>inner<a href="#fnref1" role="doc-backlink">↩︎︎</a></p>
</li>
<li id="fn2">
<p><a href="#fnref2" role="doc-backlink">↩︎︎</a></p>
</li>
</ol>
</section>
"##;
    compare!(src, expected);
}
